package com.fs.hospital.mapper;

import org.apache.ibatis.annotations.Select;

public interface HospitalStatisticsMapper {




    @Select("SELECT count(*) FROM hospital_outpatient_order WHERE DATE(create_time) = CURDATE();")
    Long selectHospitalOutpatientOrderByOrderByDay();
    @Select("SELECT count(*) FROM hospital_outpatient_order WHERE `status` =1")
    Long selectHospitalOutpatientOrderByOrderByStatus();
    @Select("SELECT count(*) FROM hospital_order WHERE `status` =1")
    Long selectHospitalOrderByStatus();

    @Select("SELECT count(*) FROM hospital_pharmacy_order WHERE `status` =1")
    Long selectPharmacyOrderNum();
    @Select("SELECT count(*) FROM hospital_inspect_order WHERE `status` =1")
    Long selectInspectOrderNum();
    @Select("SELECT count(*) FROM hospital_exam_order WHERE `status` =1")
    Long selectExamOrder();
    @Select("SELECT count(*) FROM hospital_product WHERE `total_count` <100")
    Long selectProductTotalCountWarn();
    @Select("SELECT count(*) FROM hospital_product WHERE DATE(limit_date) >CURDATE()")
    Long selectProductLimitDateWarn();
    @Select("SELECT count(*) FROM hospital_product WHERE gross_rate < 10")
    Long selectGrossRateWarn();
    @Select("SELECT count(*) FROM hospital_product WHERE DATE(update_time) = CURDATE();")
    Long selectProductUpdate();
    @Select("SELECT count(*) FROM hospital_product WHERE bar_code is null")
    Long selectProductCodeWarn();
}
